==> exasol_saas_api-0.6.0.tar.gz: exasol_saas_api-0.6.0/exasol/saas/client/openapi/api/security/update_allowed_ip.py <==
from http import HTTPStatus
from typing import (
    Any,
    Dict,
    List,
    Optional,
    Union,
    cast,
)

import httpx

from ... import errors
from ...client import (
    AuthenticatedClient,
    Client,
)
from ...models.update_allowed_ip import UpdateAllowedIP
from ...types import (
    UNSET,
    Response,
)


def _get_kwargs(
    account_id: str,
    allowlist_ip_id: str,
    *,
    body: UpdateAllowedIP,

) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}


    

    

    _kwargs: Dict[str, Any] = {
        "method": "put",
        "url": "/api/v1/accounts/{account_id}/security/allowlist_ip/{allowlist_ip_id}".format(account_id=account_id,allowlist_ip_id=allowlist_ip_id,),
    }

    _body = body.to_dict()


    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Any]:
    if response.status_code == HTTPStatus.NO_CONTENT:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    account_id: str,
    allowlist_ip_id: str,
    *,
    client: AuthenticatedClient,
    body: UpdateAllowedIP,

) -> Response[Any]:
    """ 
    Args:
        account_id (str):
        allowlist_ip_id (str):
        body (UpdateAllowedIP):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
     """


    kwargs = _get_kwargs(
        account_id=account_id,
allowlist_ip_id=allowlist_ip_id,
body=body,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    account_id: str,
    allowlist_ip_id: str,
    *,
    client: AuthenticatedClient,
    body: UpdateAllowedIP,

) -> Response[Any]:
    """ 
    Args:
        account_id (str):
        allowlist_ip_id (str):
        body (UpdateAllowedIP):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
     """


    kwargs = _get_kwargs(
        account_id=account_id,
allowlist_ip_id=allowlist_ip_id,
body=body,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

==> exasol_saas_api-1.1.1.tar.gz: exasol_saas_api-1.1.1/exasol/saas/client/openapi/api/security/update_allowed_ip.py <==
from http import HTTPStatus
from typing import (
    Any,
    Optional,
    Union,
    cast,
)

import httpx

from ... import errors
from ...client import (
    AuthenticatedClient,
    Client,
)
from ...models.update_allowed_ip import UpdateAllowedIP
from ...types import (
    UNSET,
    Response,
)


def _get_kwargs(
    account_id: str,
    allowlist_ip_id: str,
    *,
    body: UpdateAllowedIP,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "put",
        "url": f"/api/v1/accounts/{account_id}/security/allowlist_ip/{allowlist_ip_id}",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Any]:
    if response.status_code == 204:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    account_id: str,
    allowlist_ip_id: str,
    *,
    client: AuthenticatedClient,
    body: UpdateAllowedIP,
) -> Response[Any]:
    """
    Args:
        account_id (str):
        allowlist_ip_id (str):
        body (UpdateAllowedIP):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        account_id=account_id,
        allowlist_ip_id=allowlist_ip_id,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    account_id: str,
    allowlist_ip_id: str,
    *,
    client: AuthenticatedClient,
    body: UpdateAllowedIP,
) -> Response[Any]:
    """
    Args:
        account_id (str):
        allowlist_ip_id (str):
        body (UpdateAllowedIP):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        account_id=account_id,
        allowlist_ip_id=allowlist_ip_id,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)
